.. EDAM documentation master file, created by
   sphinx-quickstart on Thu Feb 20 16:28:01 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

EDAM: Environmental timeseries
================================
.. toctree::
   :maxdepth: 2
   :caption: Contents:

EDAM manage
================
.. automodule:: edam.reader.manage
   :members:

EDAM models
=============
.. automodule:: edam.reader.models
   :members:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
